@@ -16,7 +16,7 @@ use crate::{
 // --------------------------------
 
 impl<'info> Validate<'info> for NewRewarder<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(self.base.is_signer, Unauthorized);
 
         assert_keys_eq!(self.claim_fee_token_account.owner, self.rewarder);
@@ -31,7 +31,7 @@ impl<'info> Validate<'info> for NewRewarder<'info> {
 }
 
 impl<'info> Validate<'info> for SetPauseAuthority<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.auth.validate()?;
         invariant!(!self.auth.rewarder.is_paused, Paused);
         Ok(())
@@ -39,7 +39,7 @@ impl<'info> Validate<'info> for SetPauseAuthority<'info> {
 }
 
 impl<'info> Validate<'info> for MutableRewarderWithPauseAuthority<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(self.pause_authority.is_signer, Unauthorized);
         assert_keys_eq!(
             self.rewarder.pause_authority,
@@ -51,7 +51,7 @@ impl<'info> Validate<'info> for MutableRewarderWithPauseAuthority<'info> {
 }
 
 impl<'info> Validate<'info> for TransferAuthority<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(!self.rewarder.is_paused, Paused);
         invariant!(self.authority.is_signer, Unauthorized);
         assert_keys_eq!(self.authority, self.rewarder.authority);
@@ -60,7 +60,7 @@ impl<'info> Validate<'info> for TransferAuthority<'info> {
 }
 
 impl<'info> Validate<'info> for AcceptAuthority<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(!self.rewarder.is_paused, Paused);
         invariant!(
             self.rewarder.pending_authority != Pubkey::default(),
@@ -76,7 +76,7 @@ impl<'info> Validate<'info> for AcceptAuthority<'info> {
 }
 
 impl<'info> Validate<'info> for SetAnnualRewards<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.auth.validate()?;
         invariant!(!self.auth.rewarder.is_paused, Paused);
         Ok(())
@@ -88,7 +88,7 @@ impl<'info> Validate<'info> for SetAnnualRewards<'info> {
 // --------------------------------
 
 impl<'info> Validate<'info> for CreateQuarry<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.auth.validate()?;
         invariant!(!self.auth.rewarder.is_paused, Paused);
         Ok(())
@@ -96,7 +96,7 @@ impl<'info> Validate<'info> for CreateQuarry<'info> {
 }
 
 impl<'info> Validate<'info> for SetRewardsShare<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.auth.validate()?;
         invariant!(!self.auth.rewarder.is_paused, Paused);
         assert_keys_eq!(self.quarry.rewarder_key, self.auth.rewarder, "rewarder");
@@ -105,7 +105,7 @@ impl<'info> Validate<'info> for SetRewardsShare<'info> {
 }
 
 impl<'info> Validate<'info> for SetFamine<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.auth.validate()?;
         invariant!(!self.auth.rewarder.is_paused, Paused);
         assert_keys_eq!(self.quarry.rewarder_key, self.auth.rewarder, "rewarder");
@@ -114,7 +114,7 @@ impl<'info> Validate<'info> for SetFamine<'info> {
 }
 
 impl<'info> Validate<'info> for UpdateQuarryRewards<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(!self.rewarder.is_paused, Paused);
         assert_keys_eq!(self.quarry.rewarder_key, self.rewarder, "rewarder");
         Ok(())
@@ -126,7 +126,7 @@ impl<'info> Validate<'info> for UpdateQuarryRewards<'info> {
 /// --------------------------------
 
 impl<'info> Validate<'info> for CreateMiner<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(!self.rewarder.is_paused, Paused);
         assert_keys_eq!(self.miner_vault.owner, self.miner);
         assert_keys_eq!(self.miner_vault.mint, self.token_mint);
@@ -146,7 +146,7 @@ impl<'info> Validate<'info> for CreateMiner<'info> {
 
 impl<'info> Validate<'info> for ClaimRewards<'info> {
     /// Validates a [ClaimRewards] accounts struct.
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         self.stake.validate()?;
         invariant!(!self.stake.rewarder.is_paused, Paused);
 
@@ -196,7 +196,7 @@ impl<'info> Validate<'info> for ClaimRewards<'info> {
 }
 
 impl<'info> Validate<'info> for UserClaim<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(!self.rewarder.is_paused, Paused);
         // authority
         invariant!(self.authority.is_signer, Unauthorized);
@@ -214,7 +214,7 @@ impl<'info> Validate<'info> for UserClaim<'info> {
 
 impl<'info> Validate<'info> for UserStake<'info> {
     /// Validates the UserStake.
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(!self.rewarder.is_paused, Paused);
         // authority
         invariant!(self.authority.is_signer, Unauthorized);
@@ -247,7 +247,7 @@ impl<'info> Validate<'info> for UserStake<'info> {
 }
 
 impl<'info> Validate<'info> for ExtractFees<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(!self.rewarder.is_paused, Paused);
 
         assert_keys_eq!(
@@ -285,7 +285,7 @@ impl<'info> Validate<'info> for ExtractFees<'info> {
 }
 
 impl<'info> Validate<'info> for MutableRewarderWithAuthority<'info> {
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(self.authority.is_signer, Unauthorized);
         assert_keys_eq!(self.rewarder.authority, self.authority, "authority");
         Ok(())
@@ -294,7 +294,7 @@ impl<'info> Validate<'info> for MutableRewarderWithAuthority<'info> {
 
 impl<'info> Validate<'info> for ReadOnlyRewarderWithAuthority<'info> {
     /// Validates the [crate::Rewarder] is correct.
-    fn validate(&self) -> ProgramResult {
+    fn validate(&self) -> Result<()> {
         invariant!(self.authority.is_signer, Unauthorized);
         assert_keys_eq!(self.authority, self.rewarder.authority);
         Ok(())
